==> build-okapi-root-0.18-sources.zip: build-okapi-root-0.18/applications/rainbow/src/main/java/net/sf/okapi/applications/rainbow/pipeline/QualityCheckPipeline.java <==
/*===========================================================================
  Copyright (C) 2010 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  This library is free software; you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by 
  the Free Software Foundation; either version 2.1 of the License, or (at 
  your option) any later version.

  This library is distributed in the hope that it will be useful, but 
  WITHOUT ANY WARRANTY; without even the implied warranty of 
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
  General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License 
  along with this library; if not, write to the Free Software Foundation, 
  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

  See also the full LGPL text here: http://www.gnu.org/copyleft/lesser.html
===========================================================================*/

package net.sf.okapi.applications.rainbow.pipeline;

import net.sf.okapi.steps.common.RawDocumentToFilterEventsStep;
import net.sf.okapi.steps.qualitycheck.QualityCheckStep;

public class QualityCheckPipeline extends PredefinedPipeline {

	public QualityCheckPipeline () {
		super("QualityCheckPipeline",
			"Quality Check");
		addStep(new RawDocumentToFilterEventsStep());
		addStep(new QualityCheckStep());
	}
	
}

==> build-okapi-root-0.23-sources.zip: build-okapi-root-0.23/applications/rainbow/src/main/java/net/sf/okapi/applications/rainbow/pipeline/QualityCheckPipeline.java <==
/*===========================================================================
  Copyright (C) 2010-2013 by the Okapi Framework contributors
-----------------------------------------------------------------------------
  This library is free software; you can redistribute it and/or modify it 
  under the terms of the GNU Lesser General Public License as published by 
  the Free Software Foundation; either version 2.1 of the License, or (at 
  your option) any later version.

  This library is distributed in the hope that it will be useful, but 
  WITHOUT ANY WARRANTY; without even the implied warranty of 
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser 
  General Public License for more details.

  You should have received a copy of the GNU Lesser General Public License 
  along with this library; if not, write to the Free Software Foundation, 
  Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307 USA

  See also the full LGPL text here: http://www.gnu.org/copyleft/lesser.html
===========================================================================*/

package net.sf.okapi.applications.rainbow.pipeline;

import net.sf.okapi.steps.common.RawDocumentToFilterEventsStep;
import net.sf.okapi.steps.inconsistencycheck.InconsistencyCheckStep;
import net.sf.okapi.steps.qualitycheck.QualityCheckStep;

public class QualityCheckPipeline extends PredefinedPipeline {

	public QualityCheckPipeline () {
		super("QualityCheckPipeline",
			"Quality Check");
		addStep(new RawDocumentToFilterEventsStep());
		addStep(new QualityCheckStep());
		addStep(new InconsistencyCheckStep());
	}
	
}
